@@ -220,7 +220,7 @@ int get_link_syntax_len(char* data, size_t len, char* link)
             if (string[index] == '\0') {
                 break;
             } else {
-                if (string[index] >= ' ' && string[index] <= '~') {
+                if (string[index] > ' ' && string[index] <= '~') {
                     /* 文字を検出した場合 (正常) */
                 } else {
                     /* reached to end. */
@@ -331,9 +331,13 @@ static cgiFormResultType cgiHtmlEscapeDataMultiLine(char *data, int len)
             if (link_syntax_len == 0) {
                 TRYPUTC(*data);
             } else {
-                o("<a href=\"h%s\">h%s</a>",
-                        link, 
-                        link);
+                if (!LINK_DISABLED) {
+                    o("<a href=\"%c%s\" rel=\"nofollow\">%c%s</a>",
+                            *data, link, 
+                            *data, link);
+                } else {
+                    o("<span class=\"link-disabled\">[link disabled]</span>");
+                }
                 data += link_syntax_len - 1;
                 len -= link_syntax_len - 1;
             }
